@@ -38,26 +38,36 @@ class ClusterClient(NamespacedClient):
         include_disk_info: t.Optional[bool] = None,
         include_yes_decisions: t.Optional[bool] = None,
         index: t.Optional[str] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         primary: t.Optional[bool] = None,
         shard: t.Optional[int] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Provides explanations for shard allocations in the cluster.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-allocation-explain.html>`_
+          <p>Explain the shard allocations.
+          Get explanations for shard allocations in the cluster.
+          This API accepts the current_node, index, primary and shard parameters in the request body or in query parameters, but not in both at the same time.
+          For unassigned shards, it provides an explanation for why the shard is unassigned.
+          For assigned shards, it provides an explanation for why the shard is remaining on its current node and has not moved or rebalanced to another node.
+          This API can be very useful when attempting to diagnose why a shard is unassigned or why a shard continues to remain on its current node when you might expect otherwise.
+          Refer to the linked documentation for examples of how to troubleshoot allocation issues using this API.</p>
 
-        :param current_node: Specifies the node ID or the name of the node to only explain
-            a shard that is currently located on the specified node.
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-allocation-explain>`_
+
+        :param current_node: Explain a shard only if it is currently located on the specified
+            node name or node ID.
         :param include_disk_info: If true, returns information about disk usage and shard
             sizes.
         :param include_yes_decisions: If true, returns YES decisions in explanation.
-        :param index: Specifies the name of the index that you would like an explanation
-            for.
-        :param primary: If true, returns explanation for the primary shard for the given
-            shard ID.
-        :param shard: Specifies the ID of the shard that you would like an explanation
+        :param index: The name of the index that you would like an explanation for.
+        :param master_timeout: Period to wait for a connection to the master node.
+        :param primary: If true, returns an explanation for the primary shard for the
+            specified shard ID.
+        :param shard: An identifier for the shard that you would like an explanation
             for.
         """
         __path_parts: t.Dict[str, str] = {}
@@ -74,6 +84,8 @@ class ClusterClient(NamespacedClient):
             __query["include_disk_info"] = include_disk_info
         if include_yes_decisions is not None:
             __query["include_yes_decisions"] = include_yes_decisions
+        if master_timeout is not None:
+            __query["master_timeout"] = master_timeout
         if pretty is not None:
             __query["pretty"] = pretty
         if not __body:
@@ -113,11 +125,13 @@ class ClusterClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Delete component templates. Deletes component templates. Component templates
-        are building blocks for constructing index templates that specify index mappings,
-        settings, and aliases.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/indices-component-template.html>`_
+          <p>Delete component templates.
+          Component templates are building blocks for constructing index templates that specify index mappings, settings, and aliases.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-put-component-template>`_
 
         :param name: Comma-separated list or wildcard expression of component template
             names used to limit the request.
@@ -161,14 +175,20 @@ class ClusterClient(NamespacedClient):
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         wait_for_removal: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Clears cluster voting config exclusions.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/voting-config-exclusions.html>`_
+          <p>Clear cluster voting config exclusions.
+          Remove master-eligible nodes from the voting configuration exclusion list.</p>
 
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-post-voting-config-exclusions>`_
+
+        :param master_timeout: Period to wait for a connection to the master node.
         :param wait_for_removal: Specifies whether to wait for all excluded nodes to
             be removed from the cluster before clearing the voting configuration exclusions
             list. Defaults to true, meaning that all excluded nodes must be removed from
@@ -185,6 +205,8 @@ class ClusterClient(NamespacedClient):
             __query["filter_path"] = filter_path
         if human is not None:
             __query["human"] = human
+        if master_timeout is not None:
+            __query["master_timeout"] = master_timeout
         if pretty is not None:
             __query["pretty"] = pretty
         if wait_for_removal is not None:
@@ -212,10 +234,13 @@ class ClusterClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> HeadApiResponse:
         """
-        Check component templates. Returns information about whether a particular component
-        template exists.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/indices-component-template.html>`_
+          <p>Check component templates.
+          Returns information about whether a particular component template exists.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-put-component-template>`_
 
         :param name: Comma-separated list of component template names used to limit the
             request. Wildcard (*) expressions are supported.
@@ -266,11 +291,16 @@ class ClusterClient(NamespacedClient):
         local: t.Optional[bool] = None,
         master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
+        settings_filter: t.Optional[t.Union[str, t.Sequence[str]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get component templates. Retrieves information about component templates.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/indices-component-template.html>`_
+          <p>Get component templates.
+          Get information about component templates.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-put-component-template>`_
 
         :param name: Comma-separated list of component template names used to limit the
             request. Wildcard (`*`) expressions are supported.
@@ -282,6 +312,8 @@ class ClusterClient(NamespacedClient):
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
             returns an error.
+        :param settings_filter: Filter out results, for example to filter out sensitive
+            information. Supports wildcards or full settings keys
         """
         __path_parts: t.Dict[str, str]
         if name not in SKIP_IN_PATH:
@@ -307,6 +339,8 @@ class ClusterClient(NamespacedClient):
             __query["master_timeout"] = master_timeout
         if pretty is not None:
             __query["pretty"] = pretty
+        if settings_filter is not None:
+            __query["settings_filter"] = settings_filter
         __headers = {"accept": "application/json"}
         return await self.perform_request(  # type: ignore[return-value]
             "GET",
@@ -331,14 +365,22 @@ class ClusterClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns cluster-wide settings. By default, it returns only settings that have
-        been explicitly defined.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-get-settings.html>`_
+          <p>Get cluster-wide settings.</p>
+          <p>By default, it returns only settings that have been explicitly defined.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-get-settings>`_
 
         :param flat_settings: If `true`, returns settings in flat format.
-        :param include_defaults: If `true`, returns default cluster settings from the
-            local node.
+        :param include_defaults: If `true`, also returns default values for all other
+            cluster settings, reflecting the values in the `elasticsearch.yml` file of
+            one of the nodes in the cluster. If the nodes in your cluster do not all
+            have the same values in their `elasticsearch.yml` config files then the values
+            returned by this API may vary from invocation to invocation and may not reflect
+            the values that Elasticsearch uses in all situations. Use the `GET _nodes/settings`
+            API to fetch the settings for each individual node in your cluster.
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
             returns an error.
@@ -410,21 +452,23 @@ class ClusterClient(NamespacedClient):
         wait_for_no_relocating_shards: t.Optional[bool] = None,
         wait_for_nodes: t.Optional[t.Union[int, str]] = None,
         wait_for_status: t.Optional[
-            t.Union[str, t.Literal["green", "red", "yellow"]]
+            t.Union[str, t.Literal["green", "red", "unavailable", "unknown", "yellow"]]
         ] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        The cluster health API returns a simple status on the health of the cluster.
-        You can also use the API to get the health status of only specified data streams
-        and indices. For data streams, the API retrieves the health status of the stream’s
-        backing indices. The cluster health status is: green, yellow or red. On the shard
-        level, a red status indicates that the specific shard is not allocated in the
-        cluster, yellow means that the primary shard is allocated but replicas are not,
-        and green means that all shards are allocated. The index level status is controlled
-        by the worst shard status. The cluster status is controlled by the worst index
-        status.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-health.html>`_
+          <p>Get the cluster health status.</p>
+          <p>You can also use the API to get the health status of only specified data streams and indices.
+          For data streams, the API retrieves the health status of the stream’s backing indices.</p>
+          <p>The cluster health status is: green, yellow or red.
+          On the shard level, a red status indicates that the specific shard is not allocated in the cluster. Yellow means that the primary shard is allocated but replicas are not. Green means that all shards are allocated.
+          The index level status is controlled by the worst shard status.</p>
+          <p>One of the main benefits of the API is the ability to wait until the cluster reaches a certain high watermark health level.
+          The cluster status is controlled by the worst index status.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-health>`_
 
         :param index: Comma-separated list of data streams, indices, and index aliases
             used to limit the request. Wildcard expressions (`*`) are supported. To target
@@ -526,9 +570,13 @@ class ClusterClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get cluster info. Returns basic information about the cluster.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-info.html>`_
+          <p>Get cluster info.
+          Returns basic information about the cluster.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-info>`_
 
         :param target: Limits the information returned to the specific target. Supports
             a comma-separated list, such as http,ingest.
@@ -568,16 +616,16 @@ class ClusterClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns cluster-level changes (such as create index, update mapping, allocate
-        or fail shard) that have not yet been executed. NOTE: This API returns a list
-        of any pending updates to the cluster state. These are distinct from the tasks
-        reported by the Task Management API which include periodic tasks and tasks initiated
-        by the user, such as node stats, search queries, or create index requests. However,
-        if a user-initiated task such as a create index command causes a cluster state
-        update, the activity of this task might be reported by both task api and pending
-        cluster tasks API.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-pending.html>`_
+          <p>Get the pending cluster tasks.
+          Get information about cluster-level changes (such as create index, update mapping, allocate or fail shard) that have not yet taken effect.</p>
+          <p>NOTE: This API returns a list of any pending updates to the cluster state.
+          These are distinct from the tasks reported by the task management API which include periodic tasks and tasks initiated by the user, such as node stats, search queries, or create index requests.
+          However, if a user-initiated task such as a create index command causes a cluster state update, the activity of this task might be reported by both task api and pending cluster tasks API.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-pending-tasks>`_
 
         :param local: If `true`, the request retrieves information from the local node
             only. If `false`, information is retrieved from the master node.
@@ -617,16 +665,35 @@ class ClusterClient(NamespacedClient):
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         node_ids: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         node_names: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         pretty: t.Optional[bool] = None,
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Updates the cluster voting config exclusions by node ids or node names.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/voting-config-exclusions.html>`_
+          <p>Update voting configuration exclusions.
+          Update the cluster voting config exclusions by node IDs or node names.
+          By default, if there are more than three master-eligible nodes in the cluster and you remove fewer than half of the master-eligible nodes in the cluster at once, the voting configuration automatically shrinks.
+          If you want to shrink the voting configuration to contain fewer than three nodes or to remove half or more of the master-eligible nodes in the cluster at once, use this API to remove departing nodes from the voting configuration manually.
+          The API adds an entry for each specified node to the cluster’s voting configuration exclusions list.
+          It then waits until the cluster has reconfigured its voting configuration to exclude the specified nodes.</p>
+          <p>Clusters should have no voting configuration exclusions in normal operation.
+          Once the excluded nodes have stopped, clear the voting configuration exclusions with <code>DELETE /_cluster/voting_config_exclusions</code>.
+          This API waits for the nodes to be fully removed from the cluster before it returns.
+          If your cluster has voting configuration exclusions for nodes that you no longer intend to remove, use <code>DELETE /_cluster/voting_config_exclusions?wait_for_removal=false</code> to clear the voting configuration exclusions without waiting for the nodes to leave the cluster.</p>
+          <p>A response to <code>POST /_cluster/voting_config_exclusions</code> with an HTTP status code of 200 OK guarantees that the node has been removed from the voting configuration and will not be reinstated until the voting configuration exclusions are cleared by calling <code>DELETE /_cluster/voting_config_exclusions</code>.
+          If the call to <code>POST /_cluster/voting_config_exclusions</code> fails or returns a response with an HTTP status code other than 200 OK then the node may not have been removed from the voting configuration.
+          In that case, you may safely retry the call.</p>
+          <p>NOTE: Voting exclusions are required only when you remove at least half of the master-eligible nodes from a cluster in a short time period.
+          They are not required when removing master-ineligible nodes or when removing fewer than half of the master-eligible nodes.</p>
 
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-post-voting-config-exclusions>`_
+
+        :param master_timeout: Period to wait for a connection to the master node.
         :param node_ids: A comma-separated list of the persistent ids of the nodes to
             exclude from the voting configuration. If specified, you may not also specify
             node_names.
@@ -646,6 +713,8 @@ class ClusterClient(NamespacedClient):
             __query["filter_path"] = filter_path
         if human is not None:
             __query["human"] = human
+        if master_timeout is not None:
+            __query["master_timeout"] = master_timeout
         if node_ids is not None:
             __query["node_ids"] = node_ids
         if node_names is not None:
@@ -673,6 +742,7 @@ class ClusterClient(NamespacedClient):
         *,
         name: str,
         template: t.Optional[t.Mapping[str, t.Any]] = None,
+        cause: t.Optional[str] = None,
         create: t.Optional[bool] = None,
         deprecated: t.Optional[bool] = None,
         error_trace: t.Optional[bool] = None,
@@ -685,22 +755,25 @@ class ClusterClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Create or update a component template. Creates or updates a component template.
-        Component templates are building blocks for constructing index templates that
-        specify index mappings, settings, and aliases. An index template can be composed
-        of multiple component templates. To use a component template, specify it in an
-        index template’s `composed_of` list. Component templates are only applied to
-        new data streams and indices as part of a matching index template. Settings and
-        mappings specified directly in the index template or the create index request
-        override any settings or mappings specified in a component template. Component
-        templates are only used during index creation. For data streams, this includes
-        data stream creation and the creation of a stream’s backing indices. Changes
-        to component templates do not affect existing indices, including a stream’s backing
-        indices. You can use C-style `/* *\\/` block comments in component templates.
-        You can include comments anywhere in the request body except before the opening
-        curly bracket.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/indices-component-template.html>`_
+          <p>Create or update a component template.
+          Component templates are building blocks for constructing index templates that specify index mappings, settings, and aliases.</p>
+          <p>An index template can be composed of multiple component templates.
+          To use a component template, specify it in an index template’s <code>composed_of</code> list.
+          Component templates are only applied to new data streams and indices as part of a matching index template.</p>
+          <p>Settings and mappings specified directly in the index template or the create index request override any settings or mappings specified in a component template.</p>
+          <p>Component templates are only used during index creation.
+          For data streams, this includes data stream creation and the creation of a stream’s backing indices.
+          Changes to component templates do not affect existing indices, including a stream’s backing indices.</p>
+          <p>You can use C-style <code>/* *\\/</code> block comments in component templates.
+          You can include comments anywhere in the request body except before the opening curly bracket.</p>
+          <p><strong>Applying component templates</strong></p>
+          <p>You cannot directly apply a component template to a data stream or index.
+          To be applied, a component template must be included in an index template's <code>composed_of</code> list.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-put-component-template>`_
 
         :param name: Name of the component template to create. Elasticsearch includes
             the following built-in component templates: `logs-mappings`; `logs-settings`;
@@ -713,6 +786,7 @@ class ClusterClient(NamespacedClient):
             update settings API.
         :param template: The template to be applied which includes mappings, settings,
             or aliases configuration.
+        :param cause: User defined reason for create the component template.
         :param create: If `true`, this request cannot replace or update existing component
             templates.
         :param deprecated: Marks this index template as deprecated. When creating or
@@ -721,8 +795,8 @@ class ClusterClient(NamespacedClient):
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
             returns an error.
-        :param meta: Optional user metadata about the component template. May have any
-            contents. This map is not automatically generated by Elasticsearch. This
+        :param meta: Optional user metadata about the component template. It may have
+            any contents. This map is not automatically generated by Elasticsearch. This
             information is stored in the cluster state, so keeping it short is preferable.
             To unset `_meta`, replace the template without specifying this information.
         :param version: Version number used to manage component templates externally.
@@ -737,6 +811,8 @@ class ClusterClient(NamespacedClient):
         __path = f'/_component_template/{__path_parts["name"]}'
         __query: t.Dict[str, t.Any] = {}
         __body: t.Dict[str, t.Any] = body if body is not None else {}
+        if cause is not None:
+            __query["cause"] = cause
         if create is not None:
             __query["create"] = create
         if error_trace is not None:
@@ -787,15 +863,31 @@ class ClusterClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Updates the cluster settings.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-update-settings.html>`_
+          <p>Update the cluster settings.</p>
+          <p>Configure and update dynamic settings on a running cluster.
+          You can also configure dynamic settings locally on an unstarted or shut down node in <code>elasticsearch.yml</code>.</p>
+          <p>Updates made with this API can be persistent, which apply across cluster restarts, or transient, which reset after a cluster restart.
+          You can also reset transient or persistent settings by assigning them a null value.</p>
+          <p>If you configure the same setting using multiple methods, Elasticsearch applies the settings in following order of precedence: 1) Transient setting; 2) Persistent setting; 3) <code>elasticsearch.yml</code> setting; 4) Default setting value.
+          For example, you can apply a transient setting to override a persistent setting or <code>elasticsearch.yml</code> setting.
+          However, a change to an <code>elasticsearch.yml</code> setting will not override a defined transient or persistent setting.</p>
+          <p>TIP: In Elastic Cloud, use the user settings feature to configure all cluster settings. This method automatically rejects unsafe settings that could break your cluster.
+          If you run Elasticsearch on your own hardware, use this API to configure dynamic cluster settings.
+          Only use <code>elasticsearch.yml</code> for static cluster settings and node settings.
+          The API doesn’t require a restart and ensures a setting’s value is the same on all nodes.</p>
+          <p>WARNING: Transient cluster settings are no longer recommended. Use persistent cluster settings instead.
+          If a cluster becomes unstable, transient settings can clear unexpectedly, resulting in a potentially undesired cluster configuration.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-put-settings>`_
 
         :param flat_settings: Return settings in flat format (default: false)
         :param master_timeout: Explicit operation timeout for connection to master node
-        :param persistent:
+        :param persistent: The settings that persist after the cluster restarts.
         :param timeout: Explicit operation timeout
-        :param transient:
+        :param transient: The settings that do not persist after the cluster restarts.
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_cluster/settings"
@@ -841,11 +933,21 @@ class ClusterClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        The cluster remote info API allows you to retrieve all of the configured remote
-        cluster information. It returns connection and endpoint information keyed by
-        the configured remote cluster alias.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-remote-info.html>`_
+          <p>Get remote cluster information.</p>
+          <p>Get information about configured remote clusters.
+          The API returns connection and endpoint information keyed by the configured remote cluster alias.</p>
+          <blockquote>
+          <p>info
+          This API returns information that reflects current state on the local cluster.
+          The <code>connected</code> field does not necessarily reflect whether a remote cluster is down or unavailable, only whether there is currently an open connection to it.
+          Elasticsearch does not spontaneously try to reconnect to a disconnected remote cluster.
+          To trigger a reconnection, attempt a cross-cluster search, ES|QL cross-cluster search, or try the <a href="https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-indices-resolve-cluster">resolve cluster endpoint</a>.</p>
+          </blockquote>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-remote-info>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_remote/info"
@@ -888,15 +990,29 @@ class ClusterClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Allows to manually change the allocation of individual shards in the cluster.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-reroute.html>`_
+          <p>Reroute the cluster.
+          Manually change the allocation of individual shards in the cluster.
+          For example, a shard can be moved from one node to another explicitly, an allocation can be canceled, and an unassigned shard can be explicitly allocated to a specific node.</p>
+          <p>It is important to note that after processing any reroute commands Elasticsearch will perform rebalancing as normal (respecting the values of settings such as <code>cluster.routing.rebalance.enable</code>) in order to remain in a balanced state.
+          For example, if the requested allocation includes moving a shard from node1 to node2 then this may cause a shard to be moved from node2 back to node1 to even things out.</p>
+          <p>The cluster can be set to disable allocations using the <code>cluster.routing.allocation.enable</code> setting.
+          If allocations are disabled then the only allocations that will be performed are explicit ones given using the reroute command, and consequent allocations due to rebalancing.</p>
+          <p>The cluster will attempt to allocate a shard a maximum of <code>index.allocation.max_retries</code> times in a row (defaults to <code>5</code>), before giving up and leaving the shard unallocated.
+          This scenario can be caused by structural problems such as having an analyzer which refers to a stopwords file which doesn’t exist on all nodes.</p>
+          <p>Once the problem has been corrected, allocation can be manually retried by calling the reroute API with the <code>?retry_failed</code> URI query parameter, which will attempt a single retry round for these shards.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-reroute>`_
 
         :param commands: Defines the commands to perform.
-        :param dry_run: If true, then the request simulates the operation only and returns
-            the resulting state.
+        :param dry_run: If true, then the request simulates the operation. It will calculate
+            the result of applying the commands to the current cluster state and return
+            the resulting cluster state after the commands (and rebalancing) have been
+            applied; it will not actually perform the requested changes.
         :param explain: If true, then the response contains an explanation of why the
-            commands can or cannot be executed.
+            commands can or cannot run.
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
             returns an error.
@@ -975,9 +1091,25 @@ class ClusterClient(NamespacedClient):
         wait_for_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns a comprehensive information about the state of the cluster.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-state.html>`_
+          <p>Get the cluster state.
+          Get comprehensive information about the state of the cluster.</p>
+          <p>The cluster state is an internal data structure which keeps track of a variety of information needed by every node, including the identity and attributes of the other nodes in the cluster; cluster-wide settings; index metadata, including the mapping and settings for each index; the location and status of every shard copy in the cluster.</p>
+          <p>The elected master node ensures that every node in the cluster has a copy of the same cluster state.
+          This API lets you retrieve a representation of this internal state for debugging or diagnostic purposes.
+          You may need to consult the Elasticsearch source code to determine the precise meaning of the response.</p>
+          <p>By default the API will route requests to the elected master node since this node is the authoritative source of cluster states.
+          You can also retrieve the cluster state held on the node handling the API request by adding the <code>?local=true</code> query parameter.</p>
+          <p>Elasticsearch may need to expend significant effort to compute a response to this API in larger clusters, and the response may comprise a very large quantity of data.
+          If you use this API repeatedly, your cluster may become unstable.</p>
+          <p>WARNING: The response is a representation of an internal data structure.
+          Its format is not subject to the same compatibility guarantees as other more stable APIs and may change from version to version.
+          Do not query this API using external monitoring tools.
+          Instead, obtain the information you require using other more stable cluster APIs.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-state>`_
 
         :param metric: Limit the information returned to the specified metrics
         :param index: A comma-separated list of index names; use `_all` or empty string
@@ -992,7 +1124,8 @@ class ClusterClient(NamespacedClient):
             when unavailable (missing or closed)
         :param local: Return local information, do not retrieve the state from master
             node (default: false)
-        :param master_timeout: Specify timeout for connection to master
+        :param master_timeout: Timeout for waiting for new cluster state in case it is
+            blocked
         :param wait_for_metadata_version: Wait for the metadata version to be equal or
             greater than the specified metadata version
         :param wait_for_timeout: The maximum time to wait for wait_for_metadata_version
@@ -1059,11 +1192,13 @@ class ClusterClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns cluster statistics. It returns basic index metrics (shard numbers, store
-        size, memory usage) and information about the current nodes that form the cluster
-        (number, roles, os, jvm versions, memory usage, cpu and installed plugins).
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-stats.html>`_
+          <p>Get cluster statistics.
+          Get basic index metrics (shard numbers, store size, memory usage) and information about the current nodes that form the cluster (number, roles, os, jvm versions, memory usage, cpu and installed plugins).</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-cluster-stats>`_
 
         :param node_id: Comma-separated list of node filters used to limit returned information.
             Defaults to all nodes in the cluster.
