@@ -36,11 +36,16 @@ class LogstashClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes a pipeline used for Logstash Central Management.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/logstash-api-delete-pipeline.html>`_
+          <p>Delete a Logstash pipeline.
+          Delete a pipeline that is used for Logstash Central Management.
+          If the request succeeds, you receive an empty response with an appropriate status code.</p>
 
-        :param id: Identifier for the pipeline.
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-logstash-delete-pipeline>`_
+
+        :param id: An identifier for the pipeline.
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'id'")
@@ -76,11 +81,15 @@ class LogstashClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves pipelines used for Logstash Central Management.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/logstash-api-get-pipeline.html>`_
+          <p>Get Logstash pipelines.
+          Get pipelines that are used for Logstash Central Management.</p>
 
-        :param id: Comma-separated list of pipeline identifiers.
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-logstash-get-pipeline>`_
+
+        :param id: A comma-separated list of pipeline identifiers.
         """
         __path_parts: t.Dict[str, str]
         if id not in SKIP_IN_PATH:
@@ -123,11 +132,18 @@ class LogstashClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates or updates a pipeline used for Logstash Central Management.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/logstash-api-put-pipeline.html>`_
+          <p>Create or update a Logstash pipeline.</p>
+          <p>Create a pipeline that is used for Logstash Central Management.
+          If the specified pipeline exists, it is replaced.</p>
 
-        :param id: Identifier for the pipeline.
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-logstash-put-pipeline>`_
+
+        :param id: An identifier for the pipeline. Pipeline IDs must begin with a letter
+            or underscore and contain only letters, underscores, dashes, hyphens and
+            numbers.
         :param pipeline:
         """
         if id in SKIP_IN_PATH:
