@@ -42,9 +42,13 @@ class MonitoringClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Used by the monitoring features to send monitoring data.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/monitor-elasticsearch-cluster.html>`_
+          <p>Send monitoring data.
+          This API is used by the monitoring features to send monitoring data.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch>`_
 
         :param interval: Collection interval (e.g., '10s' or '10000ms') of the payload
         :param operations:
